==> gtphoto2-framework-0.1.tar.gz: gtphoto2/includes/modules/login/db.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# this is the module that does logins from the database

function do_login() {

	$SQL = "SELECT user_type_id, user_id
		FROM user
		WHERE user_name = '".clean_form_sql($_REQUEST["user_name"])."'
		AND password = PASSWORD('".clean_form_sql($_REQUEST["password"])."')";
	$result = sql_query($SQL);
	if (sql_num_rows($result) > 0) {
		$row = sql_fetch_array($result);
		$_SESSION["auth_level"] = $row["user_type_id"];
		$_SESSION["user_name"] = $_REQUEST["user_name"];
		$_SESSION["user_id"] = $_REQUEST["user_id"];
	} else {
		global $errors;
		$errors[] = "Authentication failed";
	}
}

?>

==> gtphoto2-framework-0.2.tar.gz: gtphoto2/includes/modules/login/db.php <==
<?php

/*

    GTPhoto2 - A multi user photo album
    Copyright (C) 2004 Chris Kloosterman

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

    Author's Email Address:
        kloostec@gavintech.com
    Paper Mail:
        5945 Cassino Road
        Duncan, BC, V9L 4G5, Canada

*/

# this is the module that does logins from the database

function do_login() {

	$SQL = "SELECT user_id
		FROM user
		WHERE user_name = '".clean_form_sql($_REQUEST["user_name"])."'
		AND password = PASSWORD('".clean_form_sql($_REQUEST["password"])."')";
	$result = sql_query($SQL);
	if (sql_num_rows($result) > 0) {
		$row = sql_fetch_array($result);
		$_SESSION["user_name"] = $_REQUEST["user_name"];
		$_SESSION["user_id"] = $row["user_id"];
		
		# set up user perms
		$_SESSION["types"] = array();
		$SQL = "SELECT type_id from user_type_link WHERE user_id = ".$_SESSION["user_id"]." ORDER BY type_id";
		$result = sql_query($SQL);
		if (sql_num_rows($result) > 0) {
			while ($row = sql_fetch_array($result)) {
				array_push($_SESSION["types"], $row["type_id"]);
			}
		}
	} else {
		global $errors;
		$errors[] = "Authentication failed";
	}
}

?>
